summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorIan Clatworthy <ian.clatworthy@canonical.com>2010-01-28 15:27:08 +1000
committerIan Clatworthy <ian.clatworthy@canonical.com>2010-01-28 15:27:08 +1000
commitcdf148a24642b7c4b7d0fea16fa546220046490e (patch)
treedd48ae9587de64a958cc0d3ed5c5eed33d4cd7d3
parentf8632b7a4f7d001db8d4251ff802348b3974104e (diff)
downloadpython-fastimport-cdf148a24642b7c4b7d0fea16fa546220046490e.tar.gz
Fix Monotone prefix and command name: mnt -> mtn
-rw-r--r--__init__.py12
-rw-r--r--exporters/__init__.py6
2 files changed, 9 insertions, 9 deletions
diff --git a/exporters/__init__.py b/exporters/__init__.py
index dfdf4f5..e9bf1f6 100644
--- a/exporters/__init__.py
+++ b/exporters/__init__.py
@@ -244,11 +244,11 @@ class GitExporter(_Exporter):
class MonotoneExporter(_Exporter):
def __init__(self):
- self.check_install('Monotone', '0.43', ['mnt'])
+ self.check_install('Monotone', '0.43', ['mtn'])
def generate(self, source, destination, verbose=False, custom=None):
"""Generate a fast import stream. See _Exporter.generate() for details."""
- args = ["mnt", "git_export"]
+ args = ["mtn", "git_export"]
outf, base, marks = self.get_output_info(destination)
if marks:
marks = os.path.abspath(marks)
@@ -311,7 +311,7 @@ def fast_export_from(source, destination, tool, verbose=False, custom=None):
factory = MercurialExporter
elif tool == 'git':
factory = GitExporter
- elif tool == 'mnt':
+ elif tool == 'mtn':
factory = MonotoneExporter
elif tool == 'p4':
factory = PerforceExporter
diff --git a/__init__.py b/__init__.py
index 8e1660d..46866f8 100644
--- a/__init__.py
+++ b/__init__.py
@@ -55,7 +55,7 @@ online help for the individual commands for details::
bzr help fast-export-from-darcs
bzr help fast-export-from-hg
bzr help fast-export-from-git
- bzr help fast-export-from-mnt
+ bzr help fast-export-from-mtn
bzr help fast-export-from-p4
bzr help fast-export-from-svn
@@ -144,7 +144,7 @@ class cmd_fast_import(Command):
Numerous commands are provided for generating a fast-import file
to use as input. These are named fast-export-from-xxx where xxx
is one of cvs, darcs, git, hg, mnt, p4 or svn.
To specify standard input as the input stream, use a
source name of '-' (instead of project.fi). If the source name
ends in '.gz', it is assumed to be compressed in gzip format.
@@ -850,13 +850,13 @@ class cmd_fast_export_from_git(Command):
fast_export_from(source, destination, 'git', verbose)
-class cmd_fast_export_from_mnt(Command):
+class cmd_fast_export_from_mtn(Command):
"""Generate a fast-import file from a Monotone repository.
Destination is a dump file, typically named xxx.fi where xxx is
the name of the project. If '-' is given, standard output is used.
Monotone 0.43 or later must be installed as the mnt git_export
subcommand is used under the covers to generate the stream.
The source must be a local directory.
"""
@@ -868,7 +868,7 @@ class cmd_fast_export_from_mnt(Command):
encoding_type = 'exact'
def run(self, source, destination, verbose=False):
from bzrlib.plugins.fastimport.exporters import fast_export_from
- fast_export_from(source, destination, 'mnt', verbose)
+ fast_export_from(source, destination, 'mtn', verbose)
class cmd_fast_export_from_p4(Command):
@@ -956,6 +956,6 @@ register_command(cmd_fast_export_from_cvs)
register_command(cmd_fast_export_from_darcs)
register_command(cmd_fast_export_from_hg)
register_command(cmd_fast_export_from_git)
-register_command(cmd_fast_export_from_mnt)
+register_command(cmd_fast_export_from_mtn)
register_command(cmd_fast_export_from_p4)
register_command(cmd_fast_export_from_svn)
@@ -144,7 +144,7 @@ class cmd_fast_import(Command):
Numerous commands are provided for generating a fast-import file
to use as input. These are named fast-export-from-xxx where xxx
- is one of cvs, darcs, git, hg, mnt, p4 or svn.
+ is one of cvs, darcs, git, hg, mtn, p4 or svn.
To specify standard input as the input stream, use a
source name of '-' (instead of project.fi). If the source name
@@ -850,13 +850,13 @@ class cmd_fast_export_from_git(Command):
Destination is a dump file, typically named xxx.fi where xxx is
the name of the project. If '-' is given, standard output is used.
- Monotone 0.43 or later must be installed as the mnt git_export
+ Monotone 0.43 or later must be installed as the mtn git_export
subcommand is used under the covers to generate the stream.
The source must be a local directory.